@@ -488,7 +488,7 @@ class PackagesDB:
                 deps.append(dep)
                 dep_pkg = self.get_package(dep, recurse=True, resolve_virtual=True)
                 if dep_pkg is not None:
-                    more += dep_pkg.dependencies()
+                    more += [self._resolve_virtual(pkg) for pkg in dep_pkg.dependencies()]
         return deps
 
     def _get_dependency_cycle(self, package_name):
@@ -503,7 +503,7 @@ class PackagesDB:
                 dep_pkg = self.get_package(dep, recurse=True, resolve_virtual=True)
                 if dep_pkg is not None and package_name in self._get_recursive_dependencies(dep_pkg):
                     circular.append(dep)
-                    more += dep_pkg.dependencies()
+                    more += [self._resolve_virtual(pkg) for pkg in dep_pkg.dependencies()]
         return circular
 
     def _is_successfully_tested(self, package):
@@ -620,7 +620,8 @@ class PackagesDB:
         if package["Package"] in circular_deps:
             testable = True
             for dep, dep_state in dep_states:
-                if dep in circular_deps:
+                resolved = self._resolve_virtual(dep)
+                if resolved in circular_deps:
                     # allow any non-error dep_state on the cycle for testing
                     # (error states are handled by the error propagation above)
                     pass
@@ -779,6 +780,12 @@ class PackagesDB:
         else:
             return self._packages[package_name][header]
 
+    def _resolve_virtual(self, package_name):
+        if package_name in self._virtual_packages:
+            return self._virtual_packages[package_name][0]
+        else:
+            return package_name
+
     def get_package_state(self, package_name, resolve_virtual=True, recurse=True):
         self._compute_package_states()
         if package_name in self._package_state:
@@ -790,7 +797,7 @@ class PackagesDB:
             return self._package_state[package_name]
         if package_name in self._virtual_packages:
             if resolve_virtual:
-                provider = self._virtual_packages[package_name][0]
+                provider = self._resolve_virtual(package_name)
                 return self._package_state[provider]
             else:
                 return "virtual"
